@@ -71,7 +71,7 @@ curl_fetch_memory <- function(url, handle = new_handle()){
 #' @useDynLib curl R_curl_fetch_disk
 curl_fetch_disk <- function(url, path, handle = new_handle()){
   nonblocking <- isTRUE(getOption("curl_interrupt", TRUE))
-  path <- normalizePath(path, mustWork = FALSE)
+  path <- enc2native(normalizePath(path, mustWork = FALSE))
   output <- .Call(R_curl_fetch_disk, enc2utf8(url), handle, path, "wb", nonblocking)
   res <- handle_data(handle)
   res$content <- output
